searchData={"items":[{"type":"module","title":"AshAi","doc":"Documentation for `AshAi`.","ref":"AshAi.html"},{"type":"function","title":"AshAi.class_to_status/1","doc":"Turns an error class into an HTTP status code","ref":"AshAi.html#class_to_status/1"},{"type":"function","title":"AshAi.functions/1","doc":"","ref":"AshAi.html#functions/1"},{"type":"function","title":"AshAi.has_vectorize_change?/1","doc":"","ref":"AshAi.html#has_vectorize_change?/1"},{"type":"function","title":"AshAi.iex_chat/2","doc":"","ref":"AshAi.html#iex_chat/2"},{"type":"function","title":"AshAi.setup_ash_ai/2","doc":"Adds the requisite context and tool calls to allow an agent to interact with your app.","ref":"AshAi.html#setup_ash_ai/2"},{"type":"function","title":"AshAi.to_json_api_errors/4","doc":"","ref":"AshAi.html#to_json_api_errors/4"},{"type":"macro","title":"AshAi.tools/1","doc":"","ref":"AshAi.html#tools/1"},{"type":"macro","title":"AshAi.vectorize/1","doc":"","ref":"AshAi.html#vectorize/1"},{"type":"function","title":"AshAi.with_source_pointer/2","doc":"","ref":"AshAi.html#with_source_pointer/2"},{"type":"module","title":"AshAi.Actions","doc":"Builtin generic action implementations","ref":"AshAi.Actions.html"},{"type":"macro","title":"AshAi.Actions.prompt/2","doc":"","ref":"AshAi.Actions.html#prompt/2"},{"type":"module","title":"AshAi.Actions.Prompt","doc":"A generic action impl that returns structured outputs from an LLM matching the action return.\n\nTypically used via `prompt/2`, for example:\n\n```elixir\naction :analyze_sentiment, :atom do\n  constraints one_of: [:positive, :negative]\n\n  description \"\"\"\n  Analyzes the sentiment of a given piece of text to determine if it is overall positive or negative.\n\n  Does not consider swear words as inherently negative.\n  \"\"\"\n\n  argument :text, :string do\n    allow_nil? false\n    description \"The text for analysis.\"\n  end\n\n  run prompt(\n    LangChain.ChatModels.ChatOpenAI.new!(%{ model: \"gpt-4o\"}),\n    # setting `tools: true` allows it to use all exposed tools in your app\n    tools: true\n    # alternatively you can restrict it to only a set of tools\n    # tools: [:list, :of, :tool, :names]\n    # provide an optional prompt, which is an EEx template\n    # prompt: \"Analyze the sentiment of the following text: <%= @input.arguments.description %>\"\n  )\nend\n```\n\nThe first argument to `prompt/2` is the `LangChain` model. It can also be a 2-arity function which will be invoked\nwith the input and the context, useful for dynamically selecting the model.","ref":"AshAi.Actions.Prompt.html"},{"type":"module","title":"Dynamic Configuration (using 2-arity function) - AshAi.Actions.Prompt","doc":"For runtime configuration (like using environment variables), pass a function\nas the first argument to `prompt/2`:\n\n    run prompt(\n      fn _input, _context ->\n        LangChain.ChatModels.ChatOpenAI.new!(%{\n          model: \"gpt-4o\",\n          # this can also be configured in application config, see langchain docs for more.\n          api_key: System.get_env(\"OPENAI_API_KEY\"),\n          endpoint: System.get_env(\"OPENAI_ENDPOINT\")\n        })\n      end,\n      tools: false\n    )\n\nThis function will be executed just before the prompt is sent to the LLM.","ref":"AshAi.Actions.Prompt.html#module-dynamic-configuration-using-2-arity-function"},{"type":"module","title":"Options - AshAi.Actions.Prompt","doc":"- `:tools`: A list of tool names to expose to the agent call.\n- `:verbose?`: Set to `true` for more output to be logged.\n- `:prompt`: A custom prompt as an `EEx` template. See the prompt section below.","ref":"AshAi.Actions.Prompt.html#module-options"},{"type":"module","title":"Prompt - AshAi.Actions.Prompt","doc":"The prompt by default is generated using the action and input descriptions. You can provide your own prompt\nvia the `prompt` option which will be able to reference `@input` and `@context`.\n\nThe prompt can be a string or a tuple of two strings. The first string is the system prompt and the second string is the user message.\nIf no user message is provided, the user message will be \"perform the action\". Both are treated as EEx templates.\n\nWe have found that the \"3rd party\" style description writing paired with the format we provide by default to be\na good basis point for LLMs who are meant to accomplish a task. With this in mind, for refining your prompt,\nfirst try describing via the action description that desired outcome or operating basis of the action, as well\nas how the LLM is meant to use them. State these passively as facts. For example, above we used: \"Does not consider swear\nwords as inherently negative\" instead of instructing the LLM via \"Do not consider swear words as inherently negative\".\n\nYou are of course free to use any prompting pattern you prefer, but the end result of the above prompting pattern\nleads to having a great description of your actual logic, acting both as documentation and instructions to the\nLLM that executes the action.\n\nThe default prompt template is:\n\n```elixir\n{\"You are responsible for performing the `<%= @input.action.name %>` action.\\n\\n<%= if @input.action.description do %>\\n# Description\\n<%= @input.action.description %>\\n<% end %>\\n\\n","ref":"AshAi.Actions.Prompt.html#module-prompt"},{"type":"module","title":"Inputs\\n<%= for argument <- @input.action.arguments do %>\\n- <%= argument.name %><%= if argument.description do %>: <%= argument.description %>\\n<% end %>\\n<% end %>\\n\", - AshAi.Actions.Prompt","doc":"\"# Action Inputs\\n\\n<%= for argument <- @input.action.arguments,\\n    {:ok, value} = Ash.ActionInput.fetch_argument(@input, argument.name),\\n    {:ok, value} = Ash.Type.dump_to_embedded(argument.type, value, argument.constraints) do %>\\n  - <%= argument.name %>: <%= Jason.encode!(value) %>\\n<% end %>\\n\"}\n```","ref":"AshAi.Actions.Prompt.html#module-inputs-n-for-argument-input-action-arguments-do-n-argument-name-if-argument-description-do-argument-description-n-end-n-end-n"},{"type":"function","title":"AshAi.Actions.Prompt.run/3","doc":"Callback implementation for  Ash.Resource.Actions.Implementation.run/3 .","ref":"AshAi.Actions.Prompt.html#run/3"},{"type":"behaviour","title":"AshAi.Actions.Prompt.Adapter","doc":"Behavior for prompt-backed-action adapters.\n\nThese adapters allow for different methodologies of handling prompt-based actions.\nFor example, OpenAI supports \"structured outputs\", which will guarantee a response\nmatching a requested JSON Schema. Other services however can still be used with prompt-based\nactions by providing them a tool that should be called when the action is complete.","ref":"AshAi.Actions.Prompt.Adapter.html"},{"type":"behaviour","title":"Built in Adapters - AshAi.Actions.Prompt.Adapter","doc":"- `AshAi.Actions.Prompt.Adapter.StructuredOutput` - Use an LLM that is guaranteed to return the requested JSON Schema.\n- `AshAi.Actions.Prompt.Adapter.CompletionTool` - Use an LLM and run it until it calls a \"completion\" tool, up to `max_runs` times.\n- `AshAi.Actions.Prompt.Adapter.RequestJson` - Use an LLM and request that it responds with a specific JSON format, and attempt to parse it.\n\nSee the adapter's documentation for more.","ref":"AshAi.Actions.Prompt.Adapter.html#module-built-in-adapters"},{"type":"behaviour","title":"Custom Adapters & Adapter Options - AshAi.Actions.Prompt.Adapter","doc":"If you want to provide a custom adapter, or customize the options for an adapter,\nyou can specify the `adapter` option in your `prompt/2` call.\n\n```elixir\n\nrun prompt(%{...}, adapter: {AshAi.Actions.Prompt.Adapter.CompletionTool, max_runs: 5})\n\n```","ref":"AshAi.Actions.Prompt.Adapter.html#module-custom-adapters-adapter-options"},{"type":"callback","title":"AshAi.Actions.Prompt.Adapter.run/2","doc":"Execute a prompt request with the given data and adapter options.","ref":"AshAi.Actions.Prompt.Adapter.html#c:run/2"},{"type":"callback","title":"Parameters - AshAi.Actions.Prompt.Adapter.run/2","doc":"- `data` - An `AshAi.Actions.Prompt.Data` struct containing all the prompt information\n- `opts` - Adapter-specific options","ref":"AshAi.Actions.Prompt.Adapter.html#c:run/2-parameters"},{"type":"callback","title":"Returns - AshAi.Actions.Prompt.Adapter.run/2","doc":"- `{:ok, result}` - On successful completion\n- `{:error, reason}` - On failure","ref":"AshAi.Actions.Prompt.Adapter.html#c:run/2-returns"},{"type":"module","title":"AshAi.Actions.Prompt.Adapter.CompletionTool","doc":"An adapter that provides a \"complete_request\" tool that the LLM must call within `max_runs` messages to complete the request.","ref":"AshAi.Actions.Prompt.Adapter.CompletionTool.html"},{"type":"module","title":"Adapter Options - AshAi.Actions.Prompt.Adapter.CompletionTool","doc":"- `:max_runs` - The maximum number of times to allow the LLM to repeatedly generate responses/call tools\n  before the action is considered failed.","ref":"AshAi.Actions.Prompt.Adapter.CompletionTool.html#module-adapter-options"},{"type":"function","title":"AshAi.Actions.Prompt.Adapter.CompletionTool.run/2","doc":"Callback implementation for  AshAi.Actions.Prompt.Adapter.run/2 .","ref":"AshAi.Actions.Prompt.Adapter.CompletionTool.html#run/2"},{"type":"module","title":"AshAi.Actions.Prompt.Adapter.Data","doc":"Data structure containing all the information needed for a prompt request.","ref":"AshAi.Actions.Prompt.Adapter.Data.html"},{"type":"type","title":"AshAi.Actions.Prompt.Adapter.Data.t/0","doc":"","ref":"AshAi.Actions.Prompt.Adapter.Data.html#t:t/0"},{"type":"module","title":"AshAi.Actions.Prompt.Adapter.RequestJson","doc":"An adapter for prompt-backed actions that requests JSON output directly in the prompt.\n\nThis adapter is designed for LLMs that don't support native tool calling or structured outputs.\nIt embeds the JSON schema in the system prompt and uses LangChain's JsonProcessor to extract\nthe JSON response from markdown code blocks.","ref":"AshAi.Actions.Prompt.Adapter.RequestJson.html"},{"type":"module","title":"Adapter Options - AshAi.Actions.Prompt.Adapter.RequestJson","doc":"- `:max_retries` - Maximum number of retry attempts for invalid JSON (default: 3)\n- `:json_format` - Format to request JSON in (:markdown, :xml) (default: :markdown)\n- `:include_examples` - Examples to include in prompt. Options:\n  - `true` - Generate examples using Ash.Type.generator (default)\n  - `false` - No examples\n  - `%{\"result\" => example_data}` - Use provided example data\n  - `[%{\"result\" => example1}, %{\"result\" => example2}]` - Multiple examples","ref":"AshAi.Actions.Prompt.Adapter.RequestJson.html#module-adapter-options"},{"type":"function","title":"AshAi.Actions.Prompt.Adapter.RequestJson.run/2","doc":"Callback implementation for  AshAi.Actions.Prompt.Adapter.run/2 .","ref":"AshAi.Actions.Prompt.Adapter.RequestJson.html#run/2"},{"type":"module","title":"AshAi.Actions.Prompt.Adapter.StructuredOutput","doc":"An adapter for prompt-backed actions that leverages structured output from LLMs.\n\nThe only currently known service that supports this is OpenAI.","ref":"AshAi.Actions.Prompt.Adapter.StructuredOutput.html"},{"type":"function","title":"AshAi.Actions.Prompt.Adapter.StructuredOutput.run/2","doc":"Callback implementation for  AshAi.Actions.Prompt.Adapter.run/2 .","ref":"AshAi.Actions.Prompt.Adapter.StructuredOutput.html#run/2"},{"type":"module","title":"AshAi.Changes.Vectorize","doc":"A change that vectorizes the current values of attributes for a given record.\nUsed by the manual vectorization strategy, so you can decide\nlater when to run the vectorization action.","ref":"AshAi.Changes.Vectorize.html"},{"type":"function","title":"AshAi.Changes.Vectorize.atomic/3","doc":"Callback implementation for  Ash.Resource.Change.atomic/3 .","ref":"AshAi.Changes.Vectorize.html#atomic/3"},{"type":"function","title":"AshAi.Changes.Vectorize.change/3","doc":"Callback implementation for  Ash.Resource.Change.change/3 .","ref":"AshAi.Changes.Vectorize.html#change/3"},{"type":"module","title":"AshAi.Changes.VectorizeAfterAction","doc":"Vectorizes attributes inline immediately after they are changed","ref":"AshAi.Changes.VectorizeAfterAction.html"},{"type":"function","title":"AshAi.Changes.VectorizeAfterAction.atomic/3","doc":"Callback implementation for  Ash.Resource.Change.atomic/3 .","ref":"AshAi.Changes.VectorizeAfterAction.html#atomic/3"},{"type":"function","title":"AshAi.Changes.VectorizeAfterAction.change/3","doc":"Callback implementation for  Ash.Resource.Change.change/3 .","ref":"AshAi.Changes.VectorizeAfterAction.html#change/3"},{"type":"module","title":"AshAi.Changes.VectorizeAfterActionObanTrigger","doc":"Run an ash_oban trigger when embeddings need to be regenerated.","ref":"AshAi.Changes.VectorizeAfterActionObanTrigger.html"},{"type":"function","title":"AshAi.Changes.VectorizeAfterActionObanTrigger.atomic/3","doc":"Callback implementation for  Ash.Resource.Change.atomic/3 .","ref":"AshAi.Changes.VectorizeAfterActionObanTrigger.html#atomic/3"},{"type":"function","title":"AshAi.Changes.VectorizeAfterActionObanTrigger.change/3","doc":"Callback implementation for  Ash.Resource.Change.change/3 .","ref":"AshAi.Changes.VectorizeAfterActionObanTrigger.html#change/3"},{"type":"module","title":"AshAi.Checks.ActorIsAshAi","doc":"A check that is true when the actor is `%AshAi{}`","ref":"AshAi.Checks.ActorIsAshAi.html"},{"type":"function","title":"AshAi.Checks.ActorIsAshAi.describe/1","doc":"Callback implementation for  Ash.Policy.Check.describe/1 .","ref":"AshAi.Checks.ActorIsAshAi.html#describe/1"},{"type":"function","title":"AshAi.Checks.ActorIsAshAi.eager_evaluate?/0","doc":"Callback implementation for  Ash.Policy.Check.eager_evaluate?/0 .","ref":"AshAi.Checks.ActorIsAshAi.html#eager_evaluate?/0"},{"type":"function","title":"AshAi.Checks.ActorIsAshAi.match?/3","doc":"Callback implementation for  Ash.Policy.SimpleCheck.match?/3 .","ref":"AshAi.Checks.ActorIsAshAi.html#match?/3"},{"type":"function","title":"AshAi.Checks.ActorIsAshAi.prefer_expanded_description?/0","doc":"Callback implementation for  Ash.Policy.Check.prefer_expanded_description?/0 .","ref":"AshAi.Checks.ActorIsAshAi.html#prefer_expanded_description?/0"},{"type":"function","title":"AshAi.Checks.ActorIsAshAi.requires_original_data?/2","doc":"Callback implementation for  Ash.Policy.Check.requires_original_data?/2 .","ref":"AshAi.Checks.ActorIsAshAi.html#requires_original_data?/2"},{"type":"function","title":"AshAi.Checks.ActorIsAshAi.strict_check/3","doc":"Callback implementation for  Ash.Policy.Check.strict_check/3 .","ref":"AshAi.Checks.ActorIsAshAi.html#strict_check/3"},{"type":"function","title":"AshAi.Checks.ActorIsAshAi.type/0","doc":"Callback implementation for  Ash.Policy.Check.type/0 .","ref":"AshAi.Checks.ActorIsAshAi.html#type/0"},{"type":"behaviour","title":"AshAi.EmbeddingModel","doc":"A behaviour that defines the dimensions of the vector, and how to generate the embedding","ref":"AshAi.EmbeddingModel.html"},{"type":"callback","title":"AshAi.EmbeddingModel.dimensions/1","doc":"The dimensions of generated embeddings","ref":"AshAi.EmbeddingModel.html#c:dimensions/1"},{"type":"callback","title":"AshAi.EmbeddingModel.generate/2","doc":"Generate embeddings for the given list of strings","ref":"AshAi.EmbeddingModel.html#c:generate/2"},{"type":"type","title":"AshAi.EmbeddingModel.opts/0","doc":"","ref":"AshAi.EmbeddingModel.html#t:opts/0"},{"type":"module","title":"AshAi.Info","doc":"Introspection functions for the `AshAi` extension.","ref":"AshAi.Info.html"},{"type":"function","title":"AshAi.Info.tools/1","doc":"tools DSL entities","ref":"AshAi.Info.html#tools/1"},{"type":"function","title":"AshAi.Info.vectorize_ash_oban_trigger_name/1","doc":"The name of the AshOban-trigger that will be run in order to update the record's embeddings. Defaults to `:ash_ai_update_embeddings`.","ref":"AshAi.Info.html#vectorize_ash_oban_trigger_name/1"},{"type":"function","title":"AshAi.Info.vectorize_ash_oban_trigger_name!/1","doc":"The name of the AshOban-trigger that will be run in order to update the record's embeddings. Defaults to `:ash_ai_update_embeddings`.","ref":"AshAi.Info.html#vectorize_ash_oban_trigger_name!/1"},{"type":"function","title":"AshAi.Info.vectorize_attributes/1","doc":"A keyword list of attributes to vectorize, and the name of the attribute to store the vector in","ref":"AshAi.Info.html#vectorize_attributes/1"},{"type":"function","title":"AshAi.Info.vectorize_attributes!/1","doc":"A keyword list of attributes to vectorize, and the name of the attribute to store the vector in","ref":"AshAi.Info.html#vectorize_attributes!/1"},{"type":"function","title":"AshAi.Info.vectorize_define_update_action_for_manual_strategy?/1","doc":"If true, an `ash_ai_update_embeddings` update action will be defined, which will automatically update the embeddings when run.","ref":"AshAi.Info.html#vectorize_define_update_action_for_manual_strategy?/1"},{"type":"function","title":"AshAi.Info.vectorize_full_text_name/1","doc":"The name of the attribute to store the text vector in","ref":"AshAi.Info.html#vectorize_full_text_name/1"},{"type":"function","title":"AshAi.Info.vectorize_full_text_name!/1","doc":"The name of the attribute to store the text vector in","ref":"AshAi.Info.html#vectorize_full_text_name!/1"},{"type":"function","title":"AshAi.Info.vectorize_full_text_options/1","doc":"vectorize.full_text DSL options\n\nReturns a map containing the and any configured or default values.","ref":"AshAi.Info.html#vectorize_full_text_options/1"},{"type":"function","title":"AshAi.Info.vectorize_full_text_text/1","doc":"A function or expr that takes a list of records and computes a full text string that will be vectorized. If given an expr, use `atomic_ref` to refer to new values, as this is set as an atomic update.","ref":"AshAi.Info.html#vectorize_full_text_text/1"},{"type":"function","title":"AshAi.Info.vectorize_full_text_text!/1","doc":"A function or expr that takes a list of records and computes a full text string that will be vectorized. If given an expr, use `atomic_ref` to refer to new values, as this is set as an atomic update.","ref":"AshAi.Info.html#vectorize_full_text_text!/1"},{"type":"function","title":"AshAi.Info.vectorize_full_text_used_attributes/1","doc":"If set, a vector is only regenerated when these attributes are changed","ref":"AshAi.Info.html#vectorize_full_text_used_attributes/1"},{"type":"function","title":"AshAi.Info.vectorize_full_text_used_attributes!/1","doc":"If set, a vector is only regenerated when these attributes are changed","ref":"AshAi.Info.html#vectorize_full_text_used_attributes!/1"},{"type":"function","title":"AshAi.Info.vectorize_options/1","doc":"vectorize DSL options\n\nReturns a map containing the and any configured or default values.","ref":"AshAi.Info.html#vectorize_options/1"},{"type":"function","title":"AshAi.Info.vectorize_strategy/1","doc":"How to compute the vector. Currently supported strategies are `:after_action`, `:manual`, and `:ash_oban`.","ref":"AshAi.Info.html#vectorize_strategy/1"},{"type":"function","title":"AshAi.Info.vectorize_strategy!/1","doc":"How to compute the vector. Currently supported strategies are `:after_action`, `:manual`, and `:ash_oban`.","ref":"AshAi.Info.html#vectorize_strategy!/1"},{"type":"module","title":"AshAi.Mcp","doc":"Model Context Protocol (MCP) implementation for Ash Framework.\n\nThis module implements a [Model Context Protocol (MCP)](https://modelcontextprotocol.io/) server\nthat integrates with Ash Framework, following the MCP [Streamable HTTP Transport](https://modelcontextprotocol.io/specification/2025-03-26/basic/transports#streamable-http) specification.","ref":"AshAi.Mcp.html"},{"type":"module","title":"Overview - AshAi.Mcp","doc":"This MCP implementation provides:\n\n* A fully compliant MCP server with JSON-RPC message processing\n* Session management with unique session IDs\n* Support for both JSON and Server-Sent Events (SSE) responses\n* Batch request handling\n* A foundation for integrating Ash resources with MCP clients\n* Integration with AshAi tools for AI-assisted operations","ref":"AshAi.Mcp.html#module-overview"},{"type":"module","title":"Current Features - AshAi.Mcp","doc":"* `initialize` and `shutdown` method handlers\n* Session management via GenServer processes\n* Support for streaming responses\n* Plug-compatible router for easy integration\n* Tool support for AshAi functions","ref":"AshAi.Mcp.html#module-current-features"},{"type":"module","title":"Future Enhancements - AshAi.Mcp","doc":"* OAuth integration with AshAuthentication\n* Resource-specific method handlers\n* Advanced streaming capabilities","ref":"AshAi.Mcp.html#module-future-enhancements"},{"type":"module","title":"Integration - AshAi.Mcp","doc":"","ref":"AshAi.Mcp.html#module-integration"},{"type":"module","title":"With Phoenix - AshAi.Mcp","doc":"```elixir\n# In your Phoenix router\nforward \"/mcp\", AshAi.Mcp.Router\n\n# With tools enabled\nforward \"/mcp\", AshAi.Mcp.Router, tools: [:tool1, :tool2]\n```","ref":"AshAi.Mcp.html#module-with-phoenix"},{"type":"module","title":"With Any Plug-Based Application - AshAi.Mcp","doc":"The MCP router is a standard Plug, so it can be integrated into any Plug-based application.\nYou are responsible for hosting the Plug however you prefer.","ref":"AshAi.Mcp.html#module-with-any-plug-based-application"},{"type":"module","title":"AshAi.Mcp.Dev","doc":"Place in your endpoint's code_reloading section to expose Ash dev MCP\"\n\nDefault path is `/ash_ai/mcp`","ref":"AshAi.Mcp.Dev.html"},{"type":"module","title":"AshAi.Mcp.Router","doc":"MCP Router implementing the RPC functionality over HTTP.\n\nThis router handles HTTP requests according to the Model Context Protocol specification.","ref":"AshAi.Mcp.Router.html"},{"type":"module","title":"Usage - AshAi.Mcp.Router","doc":"```elixir\nforward \"/mcp\", AshAi.Mcp.Router, tools: [:tool1, :tool2], otp_app: :my_app\n```","ref":"AshAi.Mcp.Router.html#module-usage"},{"type":"function","title":"AshAi.Mcp.Router.call/2","doc":"Callback implementation for  Plug.call/2 .","ref":"AshAi.Mcp.Router.html#call/2"},{"type":"function","title":"AshAi.Mcp.Router.init/1","doc":"Callback implementation for  Plug.init/1 .","ref":"AshAi.Mcp.Router.html#init/1"},{"type":"module","title":"AshAi.Mcp.Server","doc":"Implementation of the Model Context Protocol (MCP) RPC functionality.\n\nThis module handles HTTP requests and responses according to the MCP specification,\nsupporting both synchronous and streaming communication patterns.\nIt also handles the core JSON-RPC message processing for the protocol.","ref":"AshAi.Mcp.Server.html"},{"type":"function","title":"AshAi.Mcp.Server.get_server_name/1","doc":"Get the MCP server name","ref":"AshAi.Mcp.Server.html#get_server_name/1"},{"type":"function","title":"AshAi.Mcp.Server.get_server_version/1","doc":"Get the MCP server version","ref":"AshAi.Mcp.Server.html#get_server_version/1"},{"type":"function","title":"AshAi.Mcp.Server.handle_delete/2","doc":"Handle HTTP DELETE request for session termination","ref":"AshAi.Mcp.Server.html#handle_delete/2"},{"type":"function","title":"AshAi.Mcp.Server.handle_get/2","doc":"Process an HTTP GET request to open an SSE stream","ref":"AshAi.Mcp.Server.html#handle_get/2"},{"type":"function","title":"AshAi.Mcp.Server.handle_post/4","doc":"Process an HTTP POST request containing JSON-RPC messages","ref":"AshAi.Mcp.Server.html#handle_post/4"},{"type":"function","title":"AshAi.Mcp.Server.json_rpc_error_response/4","doc":"Create a standard JSON-RPC error response","ref":"AshAi.Mcp.Server.html#json_rpc_error_response/4"},{"type":"function","title":"AshAi.Mcp.Server.parse_json_rpc/1","doc":"Parse the JSON-RPC request","ref":"AshAi.Mcp.Server.html#parse_json_rpc/1"},{"type":"function","title":"AshAi.Mcp.Server.process_message/3","doc":"Process a single JSON-RPC message","ref":"AshAi.Mcp.Server.html#process_message/3"},{"type":"function","title":"AshAi.Mcp.Server.send_sse_event/4","doc":"Send an SSE event over the chunked connection","ref":"AshAi.Mcp.Server.html#send_sse_event/4"},{"type":"module","title":"AshAi.Tool","doc":"An action exposed to LLM agents","ref":"AshAi.Tool.html"},{"type":"module","title":"AshAi.Validations.ActorIsAshAi","doc":"A validation that passes if the actor is `%AshAi{}`","ref":"AshAi.Validations.ActorIsAshAi.html"},{"type":"task","title":"mix ash_ai.gen.chat","doc":"Generates the resources and views for a conversational UI backed by `ash_postgres` and `ash_oban`\n\nCreates a `YourApp.Chat.Conversation` and a `YourApp.Chat.Message` resource, backed by postgres and ash_oban.","ref":"Mix.Tasks.AshAi.Gen.Chat.html"},{"type":"task","title":"Example - mix ash_ai.gen.chat","doc":"```bash\nmix ash_ai.gen.chat --user Your.User.Resource --live\n```","ref":"Mix.Tasks.AshAi.Gen.Chat.html#module-example"},{"type":"task","title":"Options - mix ash_ai.gen.chat","doc":"* `--user` - The user resource.\n* `--domain` - The domain to place the resources in.\n* `--extend` - Extensions to apply to the generated resources, passed through to `mix ash.gen.resource`.","ref":"Mix.Tasks.AshAi.Gen.Chat.html#module-options"},{"type":"task","title":"mix ash_ai.gen.mcp","doc":"Sets up an MCP server for your application\n\nAdds an MCP server to your router.\nSets up Api Key authentication if\n- `--no-api-key` is not provided\n- `AshAuthentication` is available.\n- The user module is defined","ref":"Mix.Tasks.AshAi.Gen.Mcp.html"},{"type":"task","title":"Example - mix ash_ai.gen.mcp","doc":"```bash\nmix ash_ai.gen.mcp --api-key\n```","ref":"Mix.Tasks.AshAi.Gen.Mcp.html#module-example"},{"type":"task","title":"Options - mix ash_ai.gen.mcp","doc":"","ref":"Mix.Tasks.AshAi.Gen.Mcp.html#module-options"},{"type":"task","title":"Flags - mix ash_ai.gen.mcp","doc":"* `--no-api-key` - Skip setting up api key authentication and adding it to the MCP server.\n* `--user` - The user to add api key auth to, if setting it up.","ref":"Mix.Tasks.AshAi.Gen.Mcp.html#module-flags"},{"type":"task","title":"mix ash_ai.install","doc":"Installs `AshAi`. Call with `mix igniter.install ash_ai`. Requires igniter to run.","ref":"Mix.Tasks.AshAi.Install.html"},{"type":"task","title":"Example - mix ash_ai.install","doc":"```bash\nmix ash_ai.install\n```","ref":"Mix.Tasks.AshAi.Install.html#module-example"},{"type":"extras","title":"Home","doc":"# Ash AI","ref":"readme.html"},{"type":"extras","title":"MCP (Model Context Protocol) Server - Home","doc":"Both the dev & production MCP servers can be installed with\n\n`mix ash_ai.gen.mcp`","ref":"readme.html#mcp-model-context-protocol-server"},{"type":"extras","title":"Dev MCP Server - Home","doc":"To install the dev MCP server, add the `AshAi.Mcp.Dev` plug to your\nendpoint module, in the `code_reloading?` block. By default the\nmcp server will be available under `http://localhost:4000/ash_ai/mcp`.\n\n\n\n```elixir\n  if code_reloading? do\n    socket \"/phoenix/live_reload/socket\", Phoenix.LiveReloader.Socket\n\n    plug AshAi.Mcp.Dev,\n      # see the note below on protocol versions below\n      protocol_version_statement: \"2024-11-05\",\n      otp_app: :your_app\n```\n\nWe are still experimenting to see what tools (if any) are useful while developing with agents.","ref":"readme.html#dev-mcp-server"},{"type":"extras","title":"Production MCP Server - Home","doc":"AshAi provides a pre-built MCP server that can be used to expose your tool definitions to an MCP client (typically some kind of IDE, or Claude Desktop for example).\n\nThe protocol version we implement is 2025-03-26. As of this writing, many tools have not yet been updated to support this version. You will generally need to use some kind of proxy until tools have been updated accordingly. We suggest this one, provided by tidewave. https://github.com/tidewave-ai/mcp_proxy_rust#installation\n\nHowever, as of the writing of this guide, it requires setting a previous protocol version as noted above.\n\n#### Roadmap\n\n- Implement OAuth2 flow with AshAuthentication (long term)\n- Implement support for more than just tools, i.e resources etc.\n- Implement sessions, and provide a session id context to tools (this code is just commented out, and can be uncommented, just needs timeout logic for inactive sesions)\n\n#### Installation\n\n##### Authentication\n\nWe don't currently support the OAuth2 flow out of the box with AshAi, but the goal is to eventually support this with AshAuthentication. You can always implement that yourself, but the quikest way to value is to use the new `api_key` strategy.\n\nUse `mix ash_authentication.add_strategy api_key` to install it if you haven't already.\n\nThen, create a separate pipeline for `:mcp`, and add the api key plug to it:\n\n```elixir\npipeline :mcp do\n  plug AshAuthentication.Strategy.ApiKey.Plug,\n    resource: YourApp.Accounts.User,\n    # Use `required?: false` to allow unauthenticated\n    # users to connect, for example if some tools\n    # are publicly accessible.\n    required?: false\nend\n```\n\n##### Add the MCP server to your router\n\n```elixir\nscope \"/mcp\" do\n  pipe_through :mcp\n\n  forward \"/\", AshAi.Mcp.Router,\n    tools: [\n      :list,\n      :of,\n      :tools\n    ],\n    # For many tools, you will need to set the `protocol_version_statement` to the older version.\n    protocol_version_statement: \"2024-11-05\",\n    otp_app: :my_app\nend\n```\n\n## `mix ash_ai.gen.chat`\n\nThis is a new and experimental tool to generate a chat feature for your Ash & Phoenix application. It is backed by `ash_oban` and `ash_postgres`, using `pub_sub` to stream messages to the client. This is primarily a tool to get started with chat features and is by no means intended to handle every case you can come up with.\n\nTo get started:\n```\nmix ash_ai.gen.chat --live\n```\n\nThe `--live` flag indicates that you wish to generate liveviews in addition to the chat resources.\n\nIt currently requires a `user` resource to exist. If your `user` resource is not called ` .Accounts.User`, provide a custom user resource with the `--user`\nflag.\n\nTo try it out from scratch:\n\n```sh\nmix igniter.new my_app \\\n  --with phx.new \\\n  --install ash,ash_postgres,ash_phoenix \\\n  --install ash_authentication_phoenix,ash_oban \\\n  --install ash_ai@github:ash-project/ash_ai \\\n  --auth-strategy password\n```\n\nand then run:\n\n```sh\nmix ash_ai.gen.chat --live\n```\n\nYou can then start your server and visit `http://localhost:4000/chat` to see the chat feature in action. You will be prompted to register first and sign in the first time.","ref":"readme.html#production-mcp-server"},{"type":"extras","title":"Expose actions as tool calls - Home","doc":"```elixir\ndefmodule MyApp.Blog do\n  use Ash.Domain, extensions: [AshAi]\n\n  tools do\n    tool :read_posts, MyApp.Blog.Post, :read\n    tool :create_post, MyApp.Blog.Post, :create\n    tool :publish_post, MyApp.Blog.Post, :publish\n    tool :read_comments, MyApp.Blog.Comment, :read\n  end\nend\n```\n\nExpose these actions as tools. When you call `AshAi.setup_ash_ai(chain, opts)`, or `AshAi.iex_chat/2`\nit will add those as tool calls to the agent.","ref":"readme.html#expose-actions-as-tool-calls"},{"type":"extras","title":"Prompt-backed actions - Home","doc":"This allows defining an action, including input and output types, and delegating the\nimplementation to an LLM. We use structured outputs to ensure that it always returns\nthe correct data type. We also derive a default prompt from the action description and\naction inputs. See `AshAi.Actions.Prompt` for more information.\n\n```elixir\naction :analyze_sentiment, :atom do\n  constraints one_of: [:positive, :negative]\n\n  description \"\"\"\n  Analyzes the sentiment of a given piece of text to determine if it is overall positive or negative.\n  \"\"\"\n\n  argument :text, :string do\n    allow_nil? false\n    description \"The text for analysis\"\n  end\n\n  run prompt(\n    LangChain.ChatModels.ChatOpenAI.new!(%{ model: \"gpt-4o\"}),\n    # setting `tools: true` allows it to use all exposed tools in your app\n    tools: true\n    # alternatively you can restrict it to only a set of tools\n    # tools: [:list, :of, :tool, :names]\n    # provide an optional prompt, which is an EEx template\n     # prompt: \"Analyze the sentiment of the following text: <%= @input.arguments.description %>\",\n    # adapter: {Adapter, [some: :opt]}\n  )\nend\n```","ref":"readme.html#prompt-backed-actions"},{"type":"extras","title":"Adapters - Home","doc":"Adapters are used to determine how a given LLM fulfills a prompt-backed action. The adapter is guessed automatically from the model where possible.\nSee `AshAi.Actions.Prompt.Adapter` for more information.","ref":"readme.html#adapters"},{"type":"extras","title":"Setting up LangChain - Home","doc":"For any langchain models you use, you will need to configure them. See https://hexdocs.pm/langchain/ for more information.","ref":"readme.html#setting-up-langchain"},{"type":"extras","title":"Vectorization - Home","doc":"See `AshPostgres` vector setup for required steps: https://hexdocs.pm/ash_postgres/AshPostgres.Extensions.Vector.html\n\nThis extension creates a vector search action, and provides a few different strategies for how to\nupdate the embeddings when needed.\n\n```elixir\n# in a resource\n\nvectorize do\n  full_text do\n    text(fn record ->\n      \"\"\"\n      Name: #{record.name}\n      Biography: #{record.biography}\n      \"\"\"\n    end)\n\n    # When used_attributes are defined, embeddings will only be rebuilt when\n    # the listed attributes are changed in an update action.\n    used_attributes [:name, :biography]\n  end\n\n  strategy :after_action\n  attributes(name: :vectorized_name, biography: :vectorized_biography)\n\n  # See the section below on defining an embedding model\n  embedding_model MyApp.OpenAiEmbeddingModel\nend\n```\n\nIf you are using policies, add a bypass to allow us to update the vector embeddings:\n\n```elixir\nbypass action(:ash_ai_update_embeddings) do\n  authorize_if AshAi.Checks.ActorIsAshAi\nend\n```","ref":"readme.html#vectorization"},{"type":"extras","title":"Vectorization strategies - Home","doc":"Currently there are three strategies to choose from:\n\n- `:after_action` (default) - The embeddings will be updated synchronously on after every create & update action.\n- `:ash_oban` - Embeddings will be updated asynchronously through an `ash_oban`-trigger when a record is created and updated.\n- `:manual` - The embeddings will not be automatically updated in any way.\n\n### `:after_action`\n\nWill add a global change on the resource, that will run a generated action named `:ash_ai_update_embeddings`\non every update that requires the embeddings to be rebuilt. The `:ash_ai_update_embeddings`-action will be run in the `after_transaction`-phase of any create action and update action that requires the embeddings to be rebuilt.\n\nThis will make your app incredibly slow, and is not recommended for any real production usage.\n\n### `:ash_oban`\n\nRequires the `ash_oban`-dependency to be installed, and that the resource in question uses it as an extension, like this:\n\n```elixir\ndefmodule MyApp.Artist do\n  use Ash.Resource, extensions: [AshAi, AshOban]\nend\n```\n\nJust like the `:after_action`-strategy, this strategy creates an `:ash_ai_update_embeddings` update-action, and adds a global change that will run an `ash_oban`-trigger (also in the `after_transaction`-phase) whenever embeddings need to be rebuilt.\n\nYou will to define this trigger yourself, and then reference it in the `vectorize`-section like this:\n\n```elixir\ndefmodule MyApp.Artist do\n  use Ash.Resource, extensions: [AshAi, AshOban]\n\n  vectorize do\n    full_text do\n      ...\n    end\n\n    strategy :ash_oban\n    ash_oban_trigger_name :my_vectorize_trigger (default name is :ash_ai_update_embeddings)\n    ...\n  end\n\n  oban do\n    triggers do\n      trigger :my_vectorize_trigger do\n        action :ash_ai_update_embeddings\n        worker_read_action :read\n        worker_module_name __MODULE__.AshOban.Worker.UpdateEmbeddings\n        scheduler_module_name __MODULE__.AshOban.Scheduler.UpdateEmbeddings\n        scheduler_cron nil\n        list_tenants MyApp.ListTenants\n      end\n    end\n  end\nend\n```\n\n### `:manual`\n\nWill not automatically update the embeddings in any way, but will by default generated an update action\nnamed `:ash_ai_update_embeddings` that can be run on demand. If needed, you can also disable the\ngeneration of this action like this:\n\n```elixir\nvectorize do\n  full_text do\n    ...\n  end\n\n  strategy :manual\n  define_update_action_for_manual_strategy? false\n  ...\nend\n```","ref":"readme.html#vectorization-strategies"},{"type":"extras","title":"Embedding Models - Home","doc":"Embedding models are modules that are in charge of defining what the dimensions\nare of a given vector and how to generate one. This example uses `Req` to\ngenerate embeddings using `OpenAi`. To use it, you'd need to install `req`\n(`mix igniter.install req`).\n\n```elixir\ndefmodule Tunez.OpenAIEmbeddingModel do\n  use AshAi.EmbeddingModel\n\n  @impl true\n  def dimensions(_opts), do: 3072\n\n  @impl true\n  def generate(texts, _opts) do\n    api_key = System.fetch_env!(\"OPEN_AI_API_KEY\")\n\n    headers = [\n      {\"Authorization\", \"Bearer #{api_key}\"},\n      {\"Content-Type\", \"application/json\"}\n    ]\n\n    body = %{\n      \"input\" => texts,\n      \"model\" => \"text-embedding-3-large\"\n    }\n\n    response =\n      Req.post!(\"https://api.openai.com/v1/embeddings\",\n        json: body,\n        headers: headers\n      )\n\n    case response.status do\n      200 ->\n        response.body[\"data\"]\n        |> Enum.map(fn %{\"embedding\" => embedding} -> embedding end)\n        |> then(&{:ok, &1})\n\n      _status ->\n        {:error, response.body}\n    end\n  end\nend\n```\n\nOpts can be used to make embedding models that are dynamic depending on the resource, i.e\n\n```elixir\nembedding_model {MyApp.OpenAiEmbeddingModel, model: \"a-specific-model\"}\n```\n\nThose opts are available in the `_opts` argument to functions on your embedding model","ref":"readme.html#embedding-models"},{"type":"extras","title":"Using the vectors - Home","doc":"You can use expressions in filters and sorts like `vector_cosine_distance(full_text_vector, ^search_vector)`. For example:\n\n```elixir\nread :search do\n  argument :query, :string, allow_nil?: false\n\n  prepare before_action(fn query, context ->\n    case YourEmbeddingModel.generate([query.arguments.query], []) do\n      {:ok, [search_vector]} ->\n        Ash.Query.filter(\n          query,\n          vector_cosine_distance(full_text_vector, ^search_vector) < 0.5\n        )\n        |> Ash.Query.sort(\n          {calc(vector_cosine_distance(full_text_vector, ^search_vector),\n             type: :float\n           ), :asc}\n        )\n        |> Ash.Query.limit(10)\n\n      {:error, error} ->\n        {:error, error}\n    end\n  end)\nend\n```\n\n# Roadmap\n\n- more action types, like:\n  - bulk updates\n  - bulk destroys\n  - bulk creates.\n\n# How to play with it\n\n1. Setup `LangChain`\n2. Modify a `LangChain` using `AshAi.setup_ash_ai/2` or use `AshAi.iex_chat` (see below)\n2. Run `iex -S mix` and then run `AshAi.iex_chat` to start chatting with your app.\n3. Build your own chat interface. See the implementation of `AshAi.iex_chat` to see how its done.","ref":"readme.html#using-the-vectors"},{"type":"extras","title":"Contributing - Home","doc":"1. make sure to run `mix test.create && mix test.migrate` to set up locally\n1. ensure that `mix check` passes","ref":"readme.html#contributing"},{"type":"extras","title":"Using AshAi.iex_chat - Home","doc":"```elixir\ndefmodule MyApp.ChatBot do\n  alias LangChain.Chains.LLMChain\n  alias LangChain.ChatModels.ChatOpenAI\n\n  def iex_chat(actor \\\\ nil) do\n    %{\n      llm: ChatOpenAI.new!(%{model: \"gpt-4o\", stream: true}),\n      verbose: true\n    }\n    |> LLMChain.new!()\n    |> AshAi.iex_chat(actor: actor, otp_app: :my_app)\n  end\nend\n```","ref":"readme.html#using-ashai-iex_chat"},{"type":"DSL","title":"tools - dsl-ashai","doc":"","ref":"dsl-ashai.html#tools"},{"type":"DSL","title":"tools.tool - dsl-ashai","doc":"","ref":"dsl-ashai.html#tools-tool"},{"type":"DSL","title":"tools.tool.name - dsl-ashai","doc":"","ref":"dsl-ashai.html#tools-tool-name"},{"type":"DSL","title":"tools.tool.resource - dsl-ashai","doc":"","ref":"dsl-ashai.html#tools-tool-resource"},{"type":"DSL","title":"tools.tool.action - dsl-ashai","doc":"","ref":"dsl-ashai.html#tools-tool-action"},{"type":"DSL","title":"tools.tool.load - dsl-ashai","doc":"","ref":"dsl-ashai.html#tools-tool-load"},{"type":"DSL","title":"tools.tool.async - dsl-ashai","doc":"","ref":"dsl-ashai.html#tools-tool-async"},{"type":"DSL","title":"tools.tool.description - dsl-ashai","doc":"A description for the tool. Defaults to the action's description.","ref":"dsl-ashai.html#tools-tool-description"},{"type":"DSL","title":"tools.tool.identity - dsl-ashai","doc":"The identity to use for update/destroy actions. Defaults to the primary key. Set to `false` to disable entirely.","ref":"dsl-ashai.html#tools-tool-identity"},{"type":"DSL","title":"vectorize - dsl-ashai","doc":"","ref":"dsl-ashai.html#vectorize"},{"type":"DSL","title":"vectorize.attributes - dsl-ashai","doc":"A keyword list of attributes to vectorize, and the name of the attribute to store the vector in","ref":"dsl-ashai.html#vectorize-attributes"},{"type":"DSL","title":"vectorize.strategy - dsl-ashai","doc":"How to compute the vector. Currently supported strategies are `:after_action`, `:manual`, and `:ash_oban`.","ref":"dsl-ashai.html#vectorize-strategy"},{"type":"DSL","title":"vectorize.define_update_action_for_manual_strategy? - dsl-ashai","doc":"If true, an `ash_ai_update_embeddings` update action will be defined, which will automatically update the embeddings when run.","ref":"dsl-ashai.html#vectorize-define_update_action_for_manual_strategy?"},{"type":"DSL","title":"vectorize.ash_oban_trigger_name - dsl-ashai","doc":"The name of the AshOban-trigger that will be run in order to update the record's embeddings. Defaults to `:ash_ai_update_embeddings`.","ref":"dsl-ashai.html#vectorize-ash_oban_trigger_name"},{"type":"DSL","title":"vectorize.embedding_model - dsl-ashai","doc":"","ref":"dsl-ashai.html#vectorize-embedding_model"},{"type":"DSL","title":"vectorize.full_text - dsl-ashai","doc":"","ref":"dsl-ashai.html#vectorize-full_text"},{"type":"DSL","title":"vectorize.full_text.name - dsl-ashai","doc":"The name of the attribute to store the text vector in","ref":"dsl-ashai.html#vectorize-full_text-name"},{"type":"DSL","title":"vectorize.full_text.used_attributes - dsl-ashai","doc":"If set, a vector is only regenerated when these attributes are changed","ref":"dsl-ashai.html#vectorize-full_text-used_attributes"},{"type":"DSL","title":"vectorize.full_text.text - dsl-ashai","doc":"A function or expr that takes a list of records and computes a full text string that will be vectorized. If given an expr, use `atomic_ref` to refer to new values, as this is set as an atomic update.","ref":"dsl-ashai.html#vectorize-full_text-text"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v0.2.2](https://github.com/ash-project/ash_ai/compare/v0.2.1...v0.2.2) (2025-06-11)","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* properly close connection after sending the endpoint by [@zachdaniel](https://github.com/zachdaniel)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Improvements: - Change Log","doc":"* use relative paths in usage rules MCP by [@zachdaniel](https://github.com/zachdaniel)\n\n## [v0.2.1](https://github.com/ash-project/ash_ai/compare/v0.2.0...v0.2.1) (2025-06-11)","ref":"changelog.html#improvements"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* fix installer waiting for input by [@zachdaniel](https://github.com/zachdaniel)","ref":"changelog.html#bug-fixes-1"},{"type":"extras","title":"Improvements: - Change Log","doc":"* make usage rules display all and show file paths instead of by [@zachdaniel](https://github.com/zachdaniel)\n\n## [v0.2.0](https://github.com/ash-project/ash_ai/compare/v0.1.11...v0.2.0) (2025-06-10)","ref":"changelog.html#improvements-1"},{"type":"extras","title":"Features: - Change Log","doc":"* Json Processor for providers that do not support json_schema or tool calling (#49) by [@TwistingTwists](https://github.com/TwistingTwists)\n\n* improvement: Usage rules mcp integration (#60) by [Barnabas Jovanovics](https://https://github.com/barnabasJ)","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* tasks: fix prompt typo (#62) by ChristianAlexander\n\n* endpoint matching for url 'starting from' api.openai.com (#57) by [@TwistingTwists](https://github.com/TwistingTwists)\n\n* fix oban option passing by [@zachdaniel](https://github.com/zachdaniel)\n\n* require an explicit endpoint set by [@zachdaniel](https://github.com/zachdaniel)\n\n* pass tenant to AshOban.run_trigger by [@zachdaniel](https://github.com/zachdaniel)","ref":"changelog.html#bug-fixes-2"},{"type":"extras","title":"Improvements: - Change Log","doc":"* sync usage rules on project creation by [@zachdaniel](https://github.com/zachdaniel)\n\n* more context in error messages (#56) by [@TwistingTwists](https://github.com/TwistingTwists)\n\n* When using Adapter.CompletionTool (for anthropic) add the cache_control (#51) by Rodolfo Torres\n\n* more realistic handling of example generation (#50) by [@TwistingTwists](https://github.com/TwistingTwists)\n\n## [v0.1.11](https://github.com/ash-project/ash_ai/compare/v0.1.10...v0.1.11) (2025-06-04)","ref":"changelog.html#improvements-2"},{"type":"extras","title":"Improvements: - Change Log","doc":"* adapters for prompt-backed actions\n\n* add completion tool adapter, infer it from anthropic\n\n## [v0.1.10](https://github.com/ash-project/ash_ai/compare/v0.1.9...v0.1.10) (2025-05-30)","ref":"changelog.html#improvements-3"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* use after_action instead of after_transaction to afford atomic_updates (#43)\n\n## [v0.1.9](https://github.com/ash-project/ash_ai/compare/v0.1.8...v0.1.9) (2025-05-27)","ref":"changelog.html#bug-fixes-3"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* remove unnecessary source type from generated chat code\n\n## [v0.1.8](https://github.com/ash-project/ash_ai/compare/v0.1.7...v0.1.8) (2025-05-27)","ref":"changelog.html#bug-fixes-4"},{"type":"extras","title":"Improvements: - Change Log","doc":"* overhaul ash_ai.gen.chat to store tool calls\n\n* make the dev mcp path configurable (#38)\n\n## [v0.1.7](https://github.com/ash-project/ash_ai/compare/v0.1.6...v0.1.7) (2025-05-21)","ref":"changelog.html#improvements-4"},{"type":"extras","title":"Improvements: - Change Log","doc":"* Add usage rules for Ash AI\n\n## [v0.1.6](https://github.com/ash-project/ash_ai/compare/v0.1.5...v0.1.6) (2025-05-21)","ref":"changelog.html#improvements-5"},{"type":"extras","title":"Improvements: - Change Log","doc":"* Rename package_ruels to usage_rules\n\n\n## [v0.1.5](https://github.com/ash-project/ash_ai/compare/v0.1.4...v0.1.5) (2025-05-21)","ref":"changelog.html#improvements-6"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* properly display generators, add new usage-rules.md dev tool","ref":"changelog.html#bug-fixes-5"},{"type":"extras","title":"Improvements: - Change Log","doc":"* add `ash_ai.gen.package_rules` task to create a rules file\n\n## [v0.1.4](https://github.com/ash-project/ash_ai/compare/v0.1.3...v0.1.4) (2025-05-20)","ref":"changelog.html#improvements-7"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* Replace doc with description (#36)\n\n## [v0.1.3](https://github.com/ash-project/ash_ai/compare/v0.1.2...v0.1.3) (2025-05-20)","ref":"changelog.html#bug-fixes-6"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* use `description` not `doc`\n\n## [v0.1.2](https://github.com/ash-project/ash_ai/compare/v0.1.1...v0.1.2) (2025-05-20)","ref":"changelog.html#bug-fixes-7"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* improve chat ui heex template\n\n* don't reply to the initialized notification (#35)","ref":"changelog.html#bug-fixes-8"},{"type":"extras","title":"Improvements: - Change Log","doc":"* update chat heex template. (#33)\n\n## [v0.1.1](https://github.com/ash-project/ash_ai/compare/v0.1.0...v0.1.1) (2025-05-14)","ref":"changelog.html#improvements-8"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* more fixes for gen.chat message order\n\n* properly generate chat message log","ref":"changelog.html#bug-fixes-9"},{"type":"extras","title":"Improvements: - Change Log","doc":"* fix update pre_flight permission request for tools\n\n## [v0.1.0](https://github.com/ash-project/ash_ai/compare/v0.1.0...v0.1.0) (2025-05-14)","ref":"changelog.html#improvements-9"},{"type":"extras","title":"Bug Fixes: - Change Log","doc":"* always configure chat queues\n\n* Set additionalProperties to false in parameter_schema (#16)\n\n* Fix load opt not working (#12)\n\n* don't pass nil input in function/4 (#8)\n\n* Fix schema type of actions of Options (#5)\n\n* use `:asc` to put lowest distance records at the top\n\n* use correct ops in vector before action\n\n* use `message` instead of `reason`","ref":"changelog.html#bug-fixes-10"},{"type":"extras","title":"Improvements: - Change Log","doc":"* add `mix ash_ai.gen.mcp`\n\n* dev tools MCP\n\n* remove vector search action\n\n* Add an MCP server support\n\n* support tool-level descriptions\n\n* better name trigger\n\n* use bulk actions for update/destroy\n\n* first draft of `mix ash_ai.gen.chat` (#19)\n\n* allow read actions to be aggregated in addition to run\n\n* set up CI, various fixes and refactors\n\n* Add aggregates to filter properties (#15)\n\n* Add async opt to Tool\n\n* Add load opt to tool (#9)\n\n* Add tenant to opts of setup_ash_ai/2 (#4)\n\n* add installer\n\n* add tenants to action calls in functions\n\n* add `:manual` strategy\n\n* allow specifying tools by name of tool\n\n* strict modes & other various improvements\n\n* make embedding model parameterizable\n\n* remove unnecessary deps, use langchain\n\n* make embedding models for arbitrary vectorization\n\n* use configured name for tools\n\n* make the DSL more `tool` centric\n\n* add vectorize section","ref":"changelog.html#improvements-10"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}